# -*- coding: utf-8 -*-

from django.contrib import admin
from django.utils.translation import ugettext as _
from image_cropping import ImageCroppingMixin

from . import models


class CategoryAdmin(admin.ModelAdmin):
    fieldsets = (
        (_('general information'), {
            'fields': ('title', 'slug',)
        }),
        (_('visualization admin'), {
            'fields': ('status', 'ordering'),
        }),
        (_('logs admin'), {
            'fields': (
                'creator', 'date_create',
                'last_modifier', 'date_last_modify',),
        }),
    )
    list_display = (
        'get_status_display', 'title', 'slug',
    )
    readonly_fields = (
        'creator', 'date_create', 'last_modifier', 'date_last_modify',
    )
    prepopulated_fields = {'slug': ('title',)}


class ItemAdmin(ImageCroppingMixin, admin.ModelAdmin):
    fieldsets = (
        (_('general information'), {
            'fields': (
                'categories', 'tale', 'title',
                'slug', 'language', 'link',
                'publication_date', 'author',
                'source',
                'content',
            )
        }),
        (_('visualization admin'), {
            'fields': ('status', 'ordering',)
        }),
        (_('file admin'), {
            'fields': (
                'small_image', 'big_image',
                'small_cropping', 'big_cropping', 'file'),
        }),
        (_('social admin'), {
            'fields': ('linkedin_link', 'twitter_link',),
        }),
        (_('logs admin'), {
            'fields': (
                'creator', 'date_create',
                'last_modifier', 'date_last_modify',),
        }),
    )
    list_display = (
        'get_status_display', 'title', 'slug', 'language', 'publication_date', 'author', 'source', 'tale'
    )
    readonly_fields = (
        'creator', 'date_create', 'last_modifier', 'date_last_modify',
    )
    prepopulated_fields = {'slug': ('title',)}


admin.site.register(models.Category, CategoryAdmin)
admin.site.register(models.Item, ItemAdmin)
