# -*- coding: utf-8 -*-
import datetime

from django.conf import settings
from django.db.models import Q
from rest_framework import generics
from rest_framework.permissions import AllowAny

from thux.api.views import QuerysetMixin

from .. import models
from . import serializers


class ItemList(QuerysetMixin, generics.ListAPIView):
    permission_classes = (AllowAny,)
    queryset = models.Item.objects.filter(
        status=1, categories__status=1,
    ).distinct()
    serializer_class = serializers.ItemSerializer

    def get_queryset(self):
        queryset = super(ItemList, self).get_queryset()
        language_code = self.kwargs.get('language_code')
        queryset = queryset.filter(language_id=language_code)
        return queryset


class LastItemList(QuerysetMixin, generics.ListAPIView):
    permission_classes = (AllowAny,)
    now = datetime.datetime.now()
    queryset = models.Item.objects.filter(
        status=1, categories__status=1,
    ).distinct()
    serializer_class = serializers.ItemSerializer

    def get_queryset(self):
        queryset = super(LastItemList, self).get_queryset()
        language_code = self.kwargs.get('language_code')
        queryset = queryset.filter(language_id=language_code)
        if settings.SHOWCASE_ITEM_MAX_LAST_ITEMS is not None:
            queryset = queryset[:settings.SHOWCASE_ITEM_MAX_LAST_ITEMS]
        return queryset


class ItemRetrieve(generics.RetrieveAPIView):
    permission_classes = (AllowAny,)
    now = datetime.datetime.now()
    queryset = models.Item.objects.filter(
        status=1, categories__status=1,
    ).distinct()
    serializer_class = serializers.ItemSerializer
    lookup_field = 'slug'

    def get_queryset(self):
        language_code = self.kwargs.get('language_code')
        queryset = super(ItemRetrieve, self).get_queryset()
        queryset = queryset.filter(language_id=language_code)
        return queryset
